Coverage for /home/chris/workspace/django-shop/shop/admin/orderadmin: 100.00%

# Coverage for /home/chris/workspace/django-shop/shop/admin/orderadmin : 100.00%

## 9 statements 9 run 0 missing 0 excluded 0 partial

1 2 3 4 5 6 7 8 9 10 11 12 | #-*- coding: utf-8 -*- from django.contrib import admin from django.contrib.admin.options import ModelAdmin from shop.models.ordermodel import Order, OrderItem class OrderAdmin(ModelAdmin): pass admin.site.register(Order, OrderAdmin) class OrderItemAdmin(ModelAdmin): pass admin.site.register(OrderItem, OrderItemAdmin)